# none_bot_Real-ESRGAN

### 功能

使用nonebot2来作为服务接口，用于将图像进行超分辨率重建。

### 开始使用

- 使用pip安装

```
pip install nonebot_plugin_RealESRGAN
```

然后在项目内导入插件

```
nonebot.load_plugin('nonebot_plugin_RealESRGAN')
```

- 使用nb安装

```
nb plugin install nonebot_plugin_RealESRGAN
```

- 从github安装

先将源代码拉下来

```
https://github.com/ppxxxg22/nonebot_plugin_RealESRGAN
```

然后将src中的文件复制到你的bot文件中，这种方式适合做一些修改。

**详细的使用方式可以参见[此处](https://github.com/ppxxxg22/nonebot_plugin_RealESRGAN)**
